@@ -9,14 +9,14 @@ use File::Spec::Functions qw/catdir/;
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-    $VERSION = '0.27';
+    $VERSION = '0.28';
     @ISA     = qw{Module::Install::Base};
 }
 
 # check for big-endian                                                                                                                                                                                                                
 my $endianess = $Config{byteorder};
 my $ccflags = "";
-if ($ccflags == 4321) {
+if ($endianess == 4321) {
     $ccflags = " -DMONGO_BIG_ENDIAN=1 ";
 }
 
@@ -25,10 +25,10 @@ sub mongo {
 
     if ($Config{osname} eq 'darwin') {
         $ccflags = $ccflags . ' -g -pipe -fno-common -DPERL_DARWIN -no-cpp-precomp -fno-strict-aliasing -Wdeclaration-after-statement -I/usr/local/include';
-        $self->makemaker_args( CCFLAGS => $ccflags);
         $self->makemaker_args( LDDLFLAGS => ' -bundle -undefined dynamic_lookup -L/usr/local/lib');
     }
 
+    $self->makemaker_args( CCFLAGS => $ccflags);
     $self->xs_files;
 
     $self->makemaker_args( INC   => '-I. ' );
