@@ -15,7 +15,7 @@
 #
 
 package MongoDB::Collection;
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 # ABSTRACT: A Mongo Collection
 
@@ -23,10 +23,6 @@ our $VERSION = '0.27';
 
 MongoDB::Collection - A Mongo Collection
 
-=head1 VERSION
-
-version 0.27
-
 =cut
 
 use Tie::IxHash;
@@ -172,9 +168,9 @@ The optional C<$options> parameter can be used to specify if this is a safe
 insert.  A safe insert will check with the database if the insert succeeded and
 confess that it did not, if an error occured.
 
-=head2 batch_insert (@array, \%options)
+=head2 batch_insert (\@array, \%options)
 
-    my @ids = $collection->batch_insert(({name => "Joe"}, {name => "Fred"}, {name => "Sam"}));
+    my @ids = $collection->batch_insert([{name => "Joe"}, {name => "Fred"}, {name => "Sam"}]);
 
 Inserts each of the documents in the array into the database and returns an
 array of their _id fields.
