@@ -15,7 +15,7 @@
 #
 
 package MongoDB::GridFS::File;
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 # ABSTRACT: A Mongo GridFS file
 
@@ -26,10 +26,6 @@ use MongoDB::GridFS;
 
 MongoDB::GridFS::File - A Mongo GridFS file
 
-=head1 VERSION
-
-version 0.27
-
 =head1 SYNOPSIS
 
     use MongoDB::GridFS::File;
@@ -80,7 +76,7 @@ sub print {
     my ($written, $pos) = (0, 0);
     my $start_pos = $fh->getpos();
 
-    $self->_grid->chunks->ensure_index(["n"]);
+    $self->_grid->chunks->ensure_index(Tie::IxHash->new(files_id => 1, n => 1));
 
     my $cursor = $self->_grid->chunks->query({"files_id" => $self->info->{"_id"}})->sort({"n" => 1});
 
