@@ -85,7 +85,7 @@
   perl_mongo_serialize_string(&buf, ns, strlen(ns));              
 
 #define CREATE_BUF(size)                                \
-  Newx(buf.start, size, char);				\
+  New(0, buf.start, size, char);                        \
   buf.pos = buf.start;                                  \
   buf.end = buf.start + size;
 
