@@ -265,7 +265,7 @@ oid_to_sv (buffer *buf)
 static SV *
 elem_to_sv (int type, buffer *buf)
 {
-  SV *value;
+  SV *value = 0;
 
   switch(type) {
   case BSON_OID: {
@@ -285,7 +285,6 @@ elem_to_sv (int type, buffer *buf)
   }
   case BSON_STRING: {
     int len = MONGO_32(*((int*)buf->pos));
-    char *str;
     buf->pos += INT_32;
 
     // this makes a copy of the buffer
@@ -304,7 +303,7 @@ elem_to_sv (int type, buffer *buf)
   }
   case BSON_BINARY: {
     int len = MONGO_32(*(int*)buf->pos);
-    char type, *bytes;
+    char type;
 
     buf->pos += INT_32;
 
@@ -331,7 +330,7 @@ elem_to_sv (int type, buffer *buf)
   }
   case BSON_UNDEF:
   case BSON_NULL: {
-    value = &PL_sv_undef;
+    value = newSV(0);
     break;
   }
   case BSON_INT: {
@@ -346,7 +345,7 @@ elem_to_sv (int type, buffer *buf)
   }
   case BSON_DATE: {
     int64_t ms_i = MONGO_64(*(int64_t*)buf->pos);
-    SV *datetime, *ms;
+    SV *datetime, *ms, **heval;
     HV *named_params;
     buf->pos += INT_64;
     ms_i /= 1000;
@@ -355,7 +354,7 @@ elem_to_sv (int type, buffer *buf)
     ms = newSViv(ms_i);
 
     named_params = newHV();
-    hv_store(named_params, "epoch", strlen("epoch"), ms, 0);
+    heval = hv_store(named_params, "epoch", strlen("epoch"), ms, 0);
 
     value = perl_mongo_call_function("DateTime::from_epoch", 2, datetime, 
                                      sv_2mortal(newRV_inc(sv_2mortal((SV*)named_params))));
@@ -684,6 +683,7 @@ hv_to_bson (buffer *buf, SV *sv, AV *ids)
 
     (void)hv_iterinit (hv);
     while ((he = hv_iternext (hv))) {
+        SV **hval;
         STRLEN len;
         const char *key = HePV (he, len);
 
@@ -691,7 +691,13 @@ hv_to_bson (buffer *buf, SV *sv, AV *ids)
         if (ids && strcmp(key, "_id") == 0) {
           continue;
         }
-        append_sv (buf, key, HeVAL (he), NO_PREP);
+
+        /* 
+         * HeVAL doesn't return the correct value for tie(%foo, 'Tie::IxHash')
+         * so we're using hv_fetch
+         */
+        hval = hv_fetch(hv, key, len, 0);
+        append_sv (buf, key, *hval, NO_PREP);
     }
 
     perl_mongo_serialize_null(buf);
